<?php

header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the database configuration
include('config.php');

try {
    // Create a new PDO instance
    $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

    // Set the PDO error mode to exception
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch the action from the request
    $action = isset($_GET['action']) ? $_GET['action'] : '';

    switch ($action) {
        case 'fetchUniqueValues':
            // Fetch unique values for bankName or complaintnature column
            $columnName = isset($_GET['columnName']) ? $_GET['columnName'] : '';
            if ($columnName === 'bankName' || $columnName === 'complaintnature') {
                $sql = "SELECT DISTINCT $columnName FROM complaints";
                $stmt = $conn->prepare($sql);
                $stmt->execute();
                $data = $stmt->fetchAll(PDO::FETCH_COLUMN);
                echo json_encode($data);
            } else {
                echo json_encode([]);
            }
            break;
        case 'generateReport':
            // Fetch the selected report type from the request
            $reportType = isset($_GET['report']) ? $_GET['report'] : 'complaintsReceived'; // Default is complaints received
            $interval = isset($_GET['interval']) ? $_GET['interval'] : 'daily'; // Default interval is daily
            $selectedBank = isset($_GET['bank']) ? $_GET['bank'] : null; // Default is null
            $selectedComplaintNature = isset($_GET['complaintNature']) ? $_GET['complaintNature'] : null; // Default is null

            // Initialize the query parameters
            $whereClause = '';
            $params = [];

            // Adjust query based on report type
            switch ($reportType) {
                case 'complaintsReceived':
                    $whereClause = 'status = "received"';
                    break;
                case 'complaintsResolved':
                    $whereClause = 'status = "resolved"';
                    break;
                case 'complaintsUnresolved':
                    $whereClause = 'status = "unresolved"';
                    break;
                case 'complaintsClosed':
                    $whereClause = 'status = "closed"';
                    break;
                default:
                    break;
            }

            // Adjust query based on interval (daily, weekly, monthly, quarterly, yearly)
            switch ($interval) {
                case 'daily':
                    // Adjust query for daily interval
                    $groupBy = 'date';
                    break;
                case 'weekly':
                    // Adjust query for weekly interval
                    $groupBy = 'YEARWEEK(date)';
                    break;
                case 'monthly':
                    // Adjust query for monthly interval
                    $groupBy = 'DATE_FORMAT(date, "%Y-%m")';
                    break;
                case 'quarterly':
                    // Adjust query for quarterly interval
                    $groupBy = 'QUARTER(date)';
                    break;
                case 'yearly':
                    // Adjust query for yearly interval
                    $groupBy = 'YEAR(date)';
                    break;
                default:
                    break;
            }

            // Construct the SQL query
            $sql = "SELECT COUNT(*) AS total, $groupBy AS interval_date FROM complaints";
            
            if (!empty($whereClause)) {
                $sql .= " WHERE $whereClause";
            }

            // Add conditions for selected bank and complaint nature
            if ($selectedBank !== null && $selectedBank !== '') {
                // Adjust query for selected bank
                $sql .= " AND bankName = :bankName";
                $params['bankName'] = $selectedBank;
            }
            if ($selectedComplaintNature !== null && $selectedComplaintNature !== '') {
                // Adjust query for selected complaint nature
                $sql .= " AND complaintnature = :complaintnature";
                $params['complaintnature'] = $selectedComplaintNature;
            }
            
            $sql .= " GROUP BY $groupBy";

            // Prepare and execute the query
            $stmt = $conn->prepare($sql);
            $stmt->execute($params);
            $data = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Return the report data as JSON
            echo json_encode($data);
            break;
        default:
            echo json_encode([]);
            break;
    }

} catch (PDOException $e) {
    // Handle database connection errors
    echo "Error: " . $e->getMessage();
}

// Close the database connection
$conn = null;

?>
