<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('config.php');

function validateAdmin($username, $password, $conn) {
    $stmt = $conn->prepare("SELECT id, password FROM admin_user WHERE username = :username");
    $stmt->bindParam(':username', $username);
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result && password_verify($password, $result['password'])) {
        return $result['id'];
    } else {
        return false;
    }
}

if ($_SERVER["REQUEST_METHOD"] == "OPTIONS") {
    // Handle OPTIONS request for CORS preflight
    // Respond with appropriate CORS headers
    header("Access-Control-Allow-Methods: POST, OPTIONS");
    echo json_encode(array("success" => true, "message" => "Options request handled successfully"));
    exit();
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $data = json_decode(file_get_contents('php://input'), true);

    $username = isset($data["username"]) ? $data["username"] : '';
    $password = isset($data["password"]) ? $data["password"] : '';

    if (!empty($username) && !empty($password)) {
        try {
            // Establish a PDO connection
            $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);
            $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Call validateAdmin() function to validate login credentials
            $adminId = validateAdmin($username, $password, $conn);

            if ($adminId) {
                session_start();
                $_SESSION['adminId'] = $adminId;

                echo json_encode(array("success" => true, "message" => "Login successful", "adminId" => $adminId));
            } else {
                echo json_encode(array("success" => false, "message" => "Invalid username/email or password"));
            }
        } catch (PDOException $e) {
            echo json_encode(array("success" => false, "message" => "Database error: " . $e->getMessage()));
        }
    } else {
        echo json_encode(array("success" => false, "message" => "Username or password is empty"));
    }
} else {
    echo json_encode(array("success" => false, "message" => "Invalid request method"));
}
?>
