<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the database configuration
include('config.php');
require 'vendor/autoload.php';

// Function to handle errors and return JSON response
function returnResponse($success, $message) {
    echo json_encode(array("success" => $success, "message" => $message));
    exit;
}

try {
    // Create a new PDO instance
    $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    if ($_SERVER["REQUEST_METHOD"] == "POST") {
        // Extract data from the POST request
        $complaintNature = isset($_POST["complaintNature"]) ? $_POST["complaintNature"] : '';
        $staffId = isset($_POST["staffId"]) ? $_POST["staffId"] : '';
        $bankName = isset($_POST["bankName"]) ? $_POST["bankName"] : '';

        // Validate input
        if (empty($complaintNature) || empty($staffId) || empty($bankName)) {
            returnResponse(false, "Please select a complaint nature, a staff member, and a bank.");
        }

        // Query to fetch the staff member from the database
        $stmt = $conn->prepare("SELECT * FROM staff WHERE staffId = ?");
        $stmt->execute([$staffId]);
        $staff = $stmt->fetch(PDO::FETCH_ASSOC);

        // Check if the staff member exists
        if (!$staff) {
            returnResponse(false, "Staff member not found.");
        }

        // Query to insert the assignment record into the database
        $assignDate = date("Y-m-d H:i:s"); // Format as 'YYYY-MM-DD HH:MM:SS'
        $stmt = $conn->prepare("INSERT INTO assigned_records (complaintnature, staffId, bankName, assign_date) VALUES (?, ?, ?, ?)");
        $stmt->execute([$complaintNature, $staffId, $bankName, $assignDate]);
        

        // Send email notification to the staff member
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        // SMTP settings
        $mail->isSMTP();
        $mail->Host = 'mail.tecbank.com.ng';
        $mail->Port = 587;
        $mail->SMTPSecure = 'tls';
        $mail->SMTPAuth = true;
        $mail->Username = 'customerservice@tecbank.com.ng';
        $mail->Password = 'c!&s?=pAtTHh';
    
        $mail->setFrom('customerservice@tecbank.com.ng', 'TECBank Customer Service');
        $mail->addAddress($staff['staffEmail']);                              
        $mail->Subject = 'Complaint Assigned To You!';
        $mail->Body    = "A complaint has been assigned to you.please confirm. Thanks!";
        
        if ($mail->send()) {
            returnResponse(true, "Complaint assigned successfully.");
        } else {
            returnResponse(false, "Failed to send email notification.");
        }
    }
} catch (PDOException $e) {
    returnResponse(false, "Database Error: " . $e->getMessage());
} catch (Exception $e) {
    returnResponse(false, "Error: " . $e->getMessage());
}


// Close the database connection
$conn = null;
?>
