<?php

header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the database configuration
include('config.php');

// Function to handle errors and return JSON response
function returnResponse($success, $data = [], $message = '') {
    echo json_encode(array("success" => $success, "data" => $data, "message" => $message));
    exit;
}

try {
    if (isset($_GET['id'])) {
        $id = $_GET['id'];

        // Create a new PDO instance
        $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Fetch assigned records with staff name for the given id
        $stmt = $conn->prepare("SELECT ar.complaintnature, s.staffName, ar.bankName, ar.assign_date FROM assigned_records ar INNER JOIN staff s ON ar.staffId = s.staffId WHERE ar.id = :id");
        $stmt->bindParam(':id', $id);                              
        $stmt->execute();

        // Check for PDO errors
        if ($stmt->errorCode() != '00000') {
            returnResponse(false, [], "PDO Error: " . implode(", ", $stmt->errorInfo()));
        }

        $assignedRecords = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if ($assignedRecords) {
            returnResponse(true, $assignedRecords);
        } else {
            returnResponse(false, [], "No assigned records found.");
        }
        
        // Close the database connection
        $conn = null;

    } else {
        returnResponse(false, [], "ID is required.");
    }

} catch (PDOException $e) {
    returnResponse(false, [], "Database Error: " . $e->getMessage());
}

?>