<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: PUT, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

require 'vendor/autoload.php'; 
include('config.php');

// Function to handle errors and return JSON response with error code
function returnResponse($success, $message, $errorCode = null) {
    if ($errorCode) {
        echo json_encode(array("success" => $success, "message" => $message, "errorCode" => $errorCode));
    } else {
        echo json_encode(array("success" => $success, "message" => $message));
    }
    exit;
}

function generateRandomPassword() {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $length = 8;
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $randomString;
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Get JSON data from request body
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, TRUE);

    $profileOption = isset($input["profileOption"]) ? $input["profileOption"] : '';
    $bankName = isset($input["bankName"]) ? $input["bankName"] : '';
    $bankEmail = isset($input["bankEmail"]) ? $input["bankEmail"] : '';
    $bankPhone = isset($input["bankPhone"]) ? $input["bankPhone"] : '';


    if (empty($profileOption) || empty($bankName) || empty($bankEmail) || empty($bankPhone)) {
        returnResponse(false, "Please provide all required fields.");
        exit; // Make sure to exit after returning the response
    }
    

    try {
        $sqlCheck = "SELECT * FROM bank_profile WHERE bankName = ? OR bankEmail = ?";
        $stmtCheck = $conn->prepare($sqlCheck);
        $stmtCheck->execute([$bankName, $bankEmail]);
        $existingStaff = $stmtCheck->fetch();

        if ($existingStaff) {
            returnResponse(false, "A Bank with the same name or email already exists.");
        }
    } catch (PDOException $e) {
        returnResponse(false, "Error checking staff: " . $e->getMessage(), $e->getCode());
    }

    $bankID = abs(crc32($bankName));
    $password = generateRandomPassword();
    $hashedPassword = password_hash($password, PASSWORD_DEFAULT);

    try {
        $sql = "INSERT INTO bank_profile (profileOption, bankName, bankEmail, bankPhone, bankID, password) VALUES (?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
    
        $stmt->bindParam(1, $profileOption);
        $stmt->bindParam(2, $bankName);
        $stmt->bindParam(3, $bankEmail);
        $stmt->bindParam(4, $bankPhone);
        $stmt->bindParam(5, $bankID);
        $stmt->bindParam(6, $hashedPassword);
    
        $stmt->execute();

        $mail = new PHPMailer\PHPMailer\PHPMailer(true);
        try {
            $mail->SMTPDebug = 2;
            $mail->isSMTP();
            $mail->Host = 'mail.tecbank.com.ng';
            $mail->Port = 587;
            $mail->SMTPSecure = 'tls';
            $mail->SMTPAuth = true;
            $mail->Username = 'customerservice@tecbank.com.ng';
            $mail->Password = 'c!&s?=pAtTHh';

            $mail->setFrom('customerservice@tecbank.com.ng', 'Your Name');
            $mail->addAddress($bankEmail);     

            $mail->isHTML(true);                                  
            $mail->Subject = 'Your Login Details';
            $mail->Body    = 'Hello ' . $bankName . '!<br><br>Your  bankprofile has been created on the CPD Portal, below are your login details:<br><br>Bank ID: ' . $bankID . '<br>Password: ' . $password;        

            $mail->send();
            returnResponse(true, "Bank profile successfully created!. Email sent to staff email containing with login details.");
        } catch (Exception $e) {
            returnResponse(true, "Bank profile added successfully. Failed to send email: " . $mail->ErrorInfo, $e->getCode());
        }
    } catch (PDOException $e) {
        returnResponse(false, "Error adding bank: " . $e->getMessage(), $e->getCode());
    }
}

returnResponse(false, "Unsupported request method.");
?>
