<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('../config.php');

try {
    // Create a PDO instance
    $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

    // Set PDO to throw exceptions on errors
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Handle login request
    if ($_SERVER["REQUEST_METHOD"] == "POST") {
        // Get the raw POST data
        $input = file_get_contents('php://input');
        $data = json_decode($input, true);

        // Check if required fields are present
        if (!isset($data['bankID']) || !isset($data['password'])) {
            echo json_encode(array("success" => false, "message" => "bankID or password is empty"));
            exit; // Exit script
        }

        // Extract data
        $bankID = $data['bankID'];
        $password = $data['password'];

        // Prepare SQL statement
        $stmt = $conn->prepare("SELECT * FROM bank_profile WHERE bankID = :bankID");
        $stmt->bindParam(':bankID', $bankID);
        $stmt->execute();

        // Check if a row was returned
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($user) {
            // Debugging: Output the stored hash
            error_log("Stored hash: " . $user['password']);

            // Verify password
            if (password_verify($password, $user['password'])) {
                // Login successful
                echo json_encode(array("success" => true));
            } else {
                // Debugging: Output verification failure
                error_log("Password verification failed for user: " . $bankID);
                // Login failed
                echo json_encode(array("success" => false, "message" => "Invalid password"));
            }
        } else {
            // Debugging: Output invalid bankID
            error_log("Invalid bankID: " . $bankID);
            // Login failed
            echo json_encode(array("success" => false, "message" => "Invalid bankID"));
        }
    } elseif ($_SERVER["REQUEST_METHOD"] == "OPTIONS") {
        // Handle preflight request
        header("HTTP/1.1 200 OK");
    }
} catch(PDOException $e) {
    echo json_encode(array("success" => false, "message" => "Connection failed: " . $e->getMessage()));
}

// Close the PDO connection
$conn = null;
?>
