<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the database connection configuration
include('config.php');

// Fetch data for total complaints, pending complaints, treated complaints, and cancelled complaints from the database
$totalComplaintsQuery = "SELECT COUNT(*) as totalComplaints FROM complaints";
$pendingComplaintsQuery = "SELECT COUNT(*) as pendingComplaints FROM complaints WHERE status = 'Unresolved'";
$treatedComplaintsQuery = "SELECT COUNT(*) as treatedComplaints FROM complaints WHERE status = 'Resolved'";
$cancelledComplaintsQuery = "SELECT COUNT(*) as cancelledComplaints FROM complaints WHERE status = 'Closed'";

// Fetch data for total staff count
$totalStaffQuery = "SELECT COUNT(*) as totalStaff FROM staff";

// Fetch data for total complaints assigned to staff
$totalComplaintsAssignedToStaffQuery = "SELECT COUNT(*) as totalComplaintsAssignedToStaff FROM assigned_records";

$totalBanksQuery = "SELECT COUNT(*) as totalBanks FROM bank_profile"; // Query to fetch total number of banks

// Fetch selected bank complaints count
$selectedBankName = isset($_GET['selectedBankName']) ? $_GET['selectedBankName'] : null;
$selectedBankComplaintsCountQuery = "SELECT COUNT(*) as selectedBankComplaintsCount FROM complaints WHERE bankName = ?";
$selectedBankComplaintsCountStmt = $conn->prepare($selectedBankComplaintsCountQuery);
$selectedBankComplaintsCountStmt->execute([$selectedBankName]);
$selectedBankComplaintsCount = $selectedBankComplaintsCountStmt->fetch(PDO::FETCH_ASSOC)['selectedBankComplaintsCount'];

$totalComplaintsResult = $conn->query($totalComplaintsQuery);
$pendingComplaintsResult = $conn->query($pendingComplaintsQuery);
$treatedComplaintsResult = $conn->query($treatedComplaintsQuery);
$cancelledComplaintsResult = $conn->query($cancelledComplaintsQuery);

$totalStaffResult = $conn->query($totalStaffQuery);
$totalComplaintsAssignedToStaffResult = $conn->query($totalComplaintsAssignedToStaffQuery);

$totalBanksResult = $conn->query($totalBanksQuery); // Execute the query to fetch total number of banks

// Check for errors in your queries
if (!$totalComplaintsResult || !$pendingComplaintsResult || !$treatedComplaintsResult || !$cancelledComplaintsResult || !$totalStaffResult || !$totalComplaintsAssignedToStaffResult || !$totalBanksResult || !$selectedBankComplaintsCountStmt) {
    die("Query failed: " . $conn->error);
}

// Fetch the data
$totalComplaints = $totalComplaintsResult->fetch(PDO::FETCH_ASSOC)['totalComplaints'];
$pendingComplaints = $pendingComplaintsResult->fetch(PDO::FETCH_ASSOC)['pendingComplaints'];
$treatedComplaints = $treatedComplaintsResult->fetch(PDO::FETCH_ASSOC)['treatedComplaints'];
$cancelledComplaints = $cancelledComplaintsResult->fetch(PDO::FETCH_ASSOC)['cancelledComplaints'];

$totalStaff = $totalStaffResult->fetch(PDO::FETCH_ASSOC)['totalStaff'];
$totalComplaintsAssignedToStaff = $totalComplaintsAssignedToStaffResult->fetch(PDO::FETCH_ASSOC)['totalComplaintsAssignedToStaff'];

$totalBanks = $totalBanksResult->fetch(PDO::FETCH_ASSOC)['totalBanks']; // Fetch the total number of banks

// Fetch banks data
$banksQuery = "SELECT * FROM bank_profile";
$banksResult = $conn->query($banksQuery);

if (!$banksResult) {
    die("Query failed: " . $conn->error);
}

$banksData = $banksResult->fetchAll(PDO::FETCH_ASSOC);

// Close the database connection
$conn = null;

// Return the data as JSON
echo json_encode([
    'totalComplaints' => $totalComplaints,
    'pendingComplaints' => $pendingComplaints,
    'treatedComplaints' => $treatedComplaints,
    'cancelledComplaints' => $cancelledComplaints,
    'totalStaff' => $totalStaff,
    'totalComplaintsAssignedToStaff' => $totalComplaintsAssignedToStaff,
    'banksData' => $banksData, // Include banks data in the JSON response
    'totalBanks' => $totalBanks, // Include total number of banks
    'selectedBankComplaintsCount' => $selectedBankComplaintsCount // Include selected bank complaints count
]);
?>
