<?php

header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

require 'vendor/autoload.php';

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('config.php');

// Function to update complaint status
function updateComplaintStatus($complaint_id, $status, $resolution_date, $conn) {
    try {
        // Prepare SQL statement to update complaint status
        $stmt = $conn->prepare("UPDATE complaints SET status = :status, resolution_date = :resolution_date WHERE complaint_id = :complaint_id");

        // Bind parameters
        $stmt->bindParam(':complaint_id', $complaint_id);
        $stmt->bindParam(':status', $status);
        $stmt->bindParam(':resolution_date', $resolution_date);

        // Execute the statement
        $stmt->execute();

        return true;
    } catch (PDOException $e) {
        // Return false on error
        return false;
    }
}

try {
    // Create a new PDO instance
    $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

    // Set the PDO error mode to exception
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Check if it's a POST request to update complaint status
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Retrieve data from the request body
        $requestData = json_decode(file_get_contents('php://input'), true);

        // Extract necessary data from request
        $complaint_id = $requestData['complaint_id'];
        $status = $requestData['status'];
        $resolution_date = $requestData['resolution_date'];

        // Update the complaint status in the database
        if (updateComplaintStatus($complaint_id, $status, $resolution_date, $conn)) {
            // Return success message if update is successful
            echo json_encode(array('success' => 'Complaint status updated successfully'));
        } else {
            // Return error message if update fails
            echo json_encode(array('error' => 'Failed to update complaint status'));
        }

        // Exit script after handling POST request
        exit;
    }

    // Prepare and execute the SQL statement to fetch complaints
    $stmt = $conn->prepare("SELECT * FROM complaints");
    $stmt->execute();

    // Fetch all complaints as an associative array
    $complaints = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Encode the complaints array to JSON format
    $jsonComplaints = json_encode($complaints);

    // Set the Content-Type header to JSON
    header('Content-Type: application/json');

    // Return the JSON data
    echo $jsonComplaints;

} catch (PDOException $e) {
    // If an error occurs, return an error message
    echo json_encode(array('error' => 'Error fetching complaints: ' . $e->getMessage()));
}

// Close the database connection
$conn = null;

?>



