<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

require 'vendor/autoload.php';

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('config.php');

// Function to insert dissatisfaction details into the database
function insertDissatisfactionDetails($complaintID, $dissatisfactionReason) {
    global $dbHost, $dbName, $dbUser, $dbPassword;

    try {
        // Create a new PDO instance
        $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

        // Set the PDO error mode to exception
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Prepare and execute SQL statement to insert dissatisfaction details
        $stmt = $conn->prepare("INSERT INTO dissatisfaction_details (complaint_id, dissatisfaction_reason) VALUES (?, ?)");
        $stmt->execute([$complaintID, $dissatisfactionReason]);

        // Return true if insertion was successful
        return true;
    } catch (PDOException $e) {
        // Log and handle any database errors
        error_log('Database Error: ' . $e->getMessage());
        return false;
    }
}

// Handle POST request
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve complaint ID and dissatisfaction reason from POST data
    $complaintID = isset($_POST["complaintID"]) ? $_POST["complaintID"] : null;
    $dissatisfactionReason = isset($_POST["dissatisfactionReason"]) ? $_POST["dissatisfactionReason"] : null;

    if ($complaintID && $dissatisfactionReason) {
        // Call function to insert dissatisfaction details
        $inserted = insertDissatisfactionDetails($complaintID, $dissatisfactionReason);

        if ($inserted) {
            echo json_encode(array("success" => "Dissatisfaction details saved successfully."));
        } else {
            echo json_encode(array("error" => "Failed to save dissatisfaction details."));
        }
    } else {
        echo json_encode(array("error" => "Complaint ID and dissatisfaction reason are required."));
    }
} else {
    // Return error message for unsupported request method
    echo json_encode(array("error" => "Unsupported request method."));
}
?>
