<?php

header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the necessary files and configurations
include('config.php'); // Your database configuration file
require 'vendor/autoload.php'; // Include Composer's autoloader for PHPMailer

// Function to handle errors and return JSON response
function returnResponse($success, $message) {
    echo json_encode(array("success" => $success, "message" => $message));
    exit;
}

// Add Admin User Endpoint
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["action"]) && $_POST["action"] == "addUser") {
    // Extract user data from POST request
    $name = $_POST["name"];
    $email = $_POST["email"];
    $password = isset($_POST["password"]) ? $_POST["password"] : generateRandomPassword(); // Generate a random password if not provided
    
    // Validate user data (you can add more validation as needed)
    if (empty($name) || empty($email) || empty($password)) {
        returnResponse(false, "Please provide all required fields.");
    }
    
    // Insert user into the database
    try {
        $sql = "INSERT INTO admin_users (username, email, password) VALUES (?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->execute([$name, $email, $password]);
        // Send email containing login details to the new user
        sendEmail($email, $name, $password);
        returnResponse(true, "Admin user added successfully.");
    } catch (PDOException $e) {
        error_log($e->getMessage()); // Log error to file
        returnResponse(false, "Error adding admin user. Please check server logs.");
    }
}

// Change Password Endpoint
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["action"]) && $_POST["action"] == "changePassword") {
    // Extract user data from POST request
    $currentPassword = $_POST["currentPassword"];
    $newPassword = $_POST["newPassword"];
    
    // Validate user data (you can add more validation as needed)
    if (empty($currentPassword) || empty($newPassword)) {
        returnResponse(false, "Please provide all required fields.");
    }
    
    // Check if the admin user exists in the database
    // You can use session data or JWT tokens to identify the logged-in user
    // For this example, let's assume the username is obtained from the session
    $username = 'example_admin_user'; // Change this to get the username from your authentication mechanism
    
    $sql = "SELECT * FROM admin_users WHERE username = ?";
    $stmt = $conn->prepare($sql);
    $stmt->execute([$username]);
    $adminUser = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$adminUser) {
        returnResponse(false, "Admin user not found.");
    }
    
    // Verify the current password
    if (!password_verify($currentPassword, $adminUser['password'])) {
        returnResponse(false, "Incorrect current password.");
    }
    
    // Hash the new password
    $hashedNewPassword = password_hash($newPassword, PASSWORD_DEFAULT);
    
    // Update the password in the database
    try {
        $sql = "UPDATE admin_users SET password = ? WHERE username = ?";
        $stmt = $conn->prepare($sql);
        $stmt->execute([$hashedNewPassword, $username]);
        returnResponse(true, "Password changed successfully.");
    } catch (PDOException $e) {
        error_log($e->getMessage()); // Log error to file
        returnResponse(false, "Error changing password. Please check server logs.");
    }
}

// Close the database connection
$conn = null;

// Function to generate a random password
function generateRandomPassword($length = 8) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $password = '';
    for ($i = 0; $i < $length; $i++) {
        $password .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $password;
}

// Function to send email containing login details to the new user
function sendEmail($to, $name, $password) {
    $mail = new PHPMailer(true);
    
    try {
        
        $mail->isSMTP();
        $mail->Host = 'mail.tecbank.com.ng'; // Your SMTP host
        $mail->Port = 587; // Your SMTP port
        $mail->SMTPSecure = 'tls'; // Enable TLS encryption
        $mail->SMTPAuth = true; // Enable SMTP authentication
        $mail->Username = 'customerservice@tecbank.com.ng'; // Your SMTP username
        $mail->Password = 'c!&s?=pAtTHh'; // Your SMTP password

        // Set email parameters
        $mail->setFrom('your@example.com', 'Your Name');
        $mail->addAddress($to);
        $mail->Subject = 'Your Login Details';
        $mail->Body = "Name: $name\nPassword: $password";
        
        // Send email
        $mail->send();
    } catch (Exception $e) {
        // Handle email sending errors
        error_log($e->getMessage()); // Log error to file
        echo "Error sending email: " . $mail->ErrorInfo;
    }
}

?>
