<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('../config.php');

try {
    // Create a PDO instance
    $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

    // Set PDO to throw exceptions on errors
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Handle login request
    if ($_SERVER["REQUEST_METHOD"] == "POST") {
        // Get the raw POST data
        $input = file_get_contents('php://input');
        $data = json_decode($input, true);

        // Check if required fields are present
        if (!isset($data['username']) || !isset($data['password'])) {
            echo json_encode(array("success" => false, "message" => "username or password is empty"));
            exit; // Exit script
        }

        // Extract data
        $username = $data['username'];
        $password = $data['password'];

        // Prepare SQL statement
        $stmt = $conn->prepare("SELECT * FROM staff WHERE username = :username");
        $stmt->bindParam(':username', $username);
        $stmt->execute();

        // Check if a row was returned
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($user) {
            $storedHash = $user['password'];

            // Debugging: Output the stored hash
            error_log("Stored hash: " . $storedHash);

            // Check if the stored hash is MD5
            if (strlen($storedHash) == 32 && ctype_xdigit($storedHash)) {
                // Verify MD5 hash
                if (md5($password) === $storedHash) {
                    // Rehash the password using bcrypt
                    $newHashedPassword = password_hash($password, PASSWORD_BCRYPT);
                    
                    // Update the password in the database
                    $updateStmt = $conn->prepare("UPDATE staff SET password = :newPassword WHERE username = :username");
                    $updateStmt->bindParam(':newPassword', $newHashedPassword);
                    $updateStmt->bindParam(':username', $username);
                    $updateStmt->execute();

                    // Login successful
                    echo json_encode(array("success" => true));
                } else {
                    // Login failed
                    error_log("Password verification failed for user (MD5): " . $username);
                    echo json_encode(array("success" => false, "message" => "Invalid password"));
                }
            } else {
                // Verify bcrypt hash
                if (password_verify($password, $storedHash)) {
                    // Login successful
                    echo json_encode(array("success" => true));
                } else {
                    // Login failed
                    error_log("Password verification failed for user: " . $username);
                    echo json_encode(array("success" => false, "message" => "Invalid password"));
                }
            }
        } else {
            // Debugging: Output invalid username
            error_log("Invalid username: " . $username);
            // Login failed
            echo json_encode(array("success" => false, "message" => "Invalid username"));
        }
    } elseif ($_SERVER["REQUEST_METHOD"] == "OPTIONS") {
        // Handle preflight request
        header("HTTP/1.1 200 OK");
    }
} catch(PDOException $e) {
    echo json_encode(array("success" => false, "message" => "Connection failed: " . $e->getMessage()));
}

// Close the PDO connection
$conn = null;
?>
