<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

require 'vendor/autoload.php';

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('config.php');

// Function to insert submission details into the database
function insertSubmissionDetails($complaintID, $submissionLink, $proofUpload) {
    global $dbHost, $dbName, $dbUser, $dbPassword;

    try {
        // Create a new PDO instance
        $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

        // Set the PDO error mode to exception
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Prepare and execute SQL statement to insert submission details
        $stmt = $conn->prepare("INSERT INTO submission_details (submission_link, proof_upload) VALUES (?, ?)");
        $stmt->execute([$submissionLink, $proofUpload]);

        // Return true if insertion was successful
        return true;
    } catch (PDOException $e) {
        // Log and handle any database errors
        error_log('Database Error: ' . $e->getMessage());
        return false;
    }
}

// Function to retrieve complaint status and name by complaint ID
function trackComplaint($complaintID) {
    global $dbHost, $dbName, $dbUser, $dbPassword;

    try {
        // Create a new PDO instance
        $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

        // Set the PDO error mode to exception
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Prepare and execute SQL statement to retrieve complaint status and name
        $stmt = $conn->prepare("SELECT YourName, status FROM complaints WHERE complaint_id = ?");
        $stmt->execute([$complaintID]);

        // Fetch the status and name
        $result = $stmt->fetch(PDO::FETCH_ASSOC);

        // Check if complaint ID exists
        if ($result) {
            return $result;
        } else {
            return array("error" => "Complaint ID not found.");
        }
    } catch (PDOException $e) {
        // Log and handle any database errors
        error_log('Database Error: ' . $e->getMessage());
        return array("error" => "An error occurred while processing your request.");
    }
}

// Handle POST request
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve complaint ID from POST data
    $complaintID = isset($_POST["complaintID"]) ? $_POST["complaintID"] : null;

    if ($complaintID) {
        // Call function to track complaint
        $result = trackComplaint($complaintID);

        // Return the result as JSON
        echo json_encode($result);
    } else {
        // Retrieve submission link and proof upload from POST data
        $submissionLink = isset($_POST["submissionLink"]) ? $_POST["submissionLink"] : null;
        $proofUpload = isset($_FILES["proofUpload"]) ? $_FILES["proofUpload"] : null;

        // Check if submission link or proof upload is provided
        if ($submissionLink || $proofUpload) {
            // Handle file upload
            $uploadDir = 'uploads/';
            $proofUploadPath = null;

            if ($proofUpload) {
                $proofUploadPath = $uploadDir . basename($proofUpload['name']);
                move_uploaded_file($proofUpload['tmp_name'], $proofUploadPath);
            }

            // Call function to insert submission details into the database
            $inserted = insertSubmissionDetails(null, $submissionLink, $proofUploadPath);

            if ($inserted) {
                echo json_encode(array("success" => "Submission details saved successfully."));
            } else {
                echo json_encode(array("error" => "Failed to save submission details."));
            }
        } else {
            // Return error message for missing submission details
            echo json_encode(array("error" => "Submission details are required."));
        }
    }
} else {
    // Return error message for unsupported request method
    echo json_encode(array("error" => "Unsupported request method."));
}

?>
