<?php

header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

require 'vendor/autoload.php'; 

// Enable error reporting for debugging purposes
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database configuration
include('config.php');

// Function to generate a random complaint ID
function generateComplaintID() {
    return 'COM' . str_pad(mt_rand(1, 9999999), 7, '0', STR_PAD_LEFT);
}

function getBankEmail($bankName) {
    $filePath = __DIR__ . '/banks.json';
    if (file_exists($filePath)) {
        $banks = json_decode(file_get_contents($filePath), true);
        if ($banks && is_array($banks)) {
            foreach ($banks as $bank) {
                if ($bank['name'] === $bankName && isset($bank['bank_email'])) {
                    return $bank['bank_email'];
                }
            }
        }
    } else {
        echo "Error: JSON file not found.";
    }
    return null;
}



// Handle form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {

    try {
        // Create a new PDO instance
        $conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);

        // Set the PDO error mode to exception
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Prepare and bind the SQL statement
        $stmt = $conn->prepare("INSERT INTO complaints (complaint_id, YourName, gender, accountName, accountNumber, amount, currency, bankName, otherbankname, date, address, states, phone1, phone2, email, complaintnature, DescriptionOfComplaint, reportedBefore, previousComplaintStatus, previousComplaintID, photoPath, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 'Unresolved')");

        // Generate complaint ID
        $complaintID = generateComplaintID();

        // Bind parameters
        $stmt->bindParam(1, $complaintID);
        $stmt->bindParam(2, $_POST["YourName"]);
        $stmt->bindParam(3, $_POST["gender"]);
        $stmt->bindParam(4, $_POST["accountName"]);
        $stmt->bindParam(5, $_POST["accountNumber"]);
        $stmt->bindParam(6, $_POST["amount"]);
        $stmt->bindParam(7, $_POST["currency"]);
        $stmt->bindParam(8, $_POST["bankName"]);
        $stmt->bindParam(9, $_POST["otherbankname"]);
        $stmt->bindParam(10, $_POST["date"]);
        $stmt->bindParam(11, $_POST["address"]);
        $stmt->bindParam(12, $_POST["states"]);
        $stmt->bindParam(13, $_POST["phone1"]);
        $stmt->bindParam(14, $_POST["phone2"]);
        $stmt->bindParam(15, $_POST["email"]);
        $stmt->bindParam(16, $_POST["complaintnature"]);
        $stmt->bindParam(17, $_POST["DescriptionOfComplaint"]);
        $stmt->bindParam(18, $_POST["reportedBefore"]);
        $stmt->bindParam(19, $_POST["previousComplaintStatus"]);
        $stmt->bindParam(20, $_POST["previousComplaintID"]);

        // Check if the "photo" index exists and is not null
        if (isset($_FILES["photo"]) && $_FILES["photo"]["error"] === UPLOAD_ERR_OK) {
            // Move the uploaded file to a directory (adjust the path accordingly)
            $targetDir = "uploads/";
            $targetFile = $targetDir . basename($_FILES["photo"]["name"]);

            if (move_uploaded_file($_FILES["photo"]["tmp_name"], $targetFile)) {
                // File uploaded successfully, update the photoPath in the database
                $stmt->bindParam(21, $targetFile); // Bind the photoPath after it's defined
            } else {
                // Handle file upload error
                echo 'Error uploading file.';
                exit(); // Terminate script execution
            }
        } else {
            // Handle case when no file was uploaded or there was an error
            echo 'No file uploaded or error occurred during upload.';
            exit(); // Terminate script execution
        }

        // Execute the prepared statement
        $stmt->execute();
        
        // Initialize PHPMailer object
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        
        // SMTP settings
        $mail->isSMTP();
        $mail->Host = 'mail.tecbank.com.ng';
        $mail->Port = 587;
        $mail->SMTPSecure = 'tls';
        $mail->SMTPAuth = true;
        $mail->Username = 'customerservice@tecbank.com.ng';
        $mail->Password = 'c!&s?=pAtTHh';
    

        // Sender and recipient
        $mail->setFrom('customerservice@tecbank.com.ng', 'Your Name');
        $mail->addAddress($_POST["email"], $_POST["YourName"]);

        // Email content
        $mail->isHTML(true); // Set email format to HTML
        $mail->Subject = "Complaint Received - Ticket ID: $complaintID";
        $mail->Body = "Thank you for submitting your complaint. Your complaint has been received, and a ticket has been opened for you. Your complaint ID and tracking number is: $complaintID";

        // Send email
        if ($mail->send()) {
            // Send a plain text response for success
            echo 'Complaint submitted successfully! Your tracking number is ' . $complaintID;
        } else {
            // Send a plain text response for email sending failure
            echo 'Email could not be sent. Mailer Error: ' . $mail->ErrorInfo;
        }

       // Send notification email to the bank
$bankEmail = getBankEmail($_POST["bankName"]); // Change $_POST["name"] to $_POST["bankName"]
if ($bankEmail !== null) {
    // Initialize PHPMailer object for sending email to the bank
    $mailToBank = new PHPMailer\PHPMailer\PHPMailer();
    // SMTP Configuration (Assuming your SMTP configuration remains the same)
    // Sender and recipient
    $mailToBank->setFrom('customerservice@tecbank.com.ng', 'Your Name');
    $mailToBank->addAddress($bankEmail);
    // Email content
    $mailToBank->isHTML(true); // Set email format to HTML
    $mailToBank->Subject = "New Complaint Submitted - Ticket ID: $complaintID";
    $mailToBank->Body = "A new complaint has been submitted by a customer regarding your bank. 
    Complaint ID: $complaintID
    Name: {$_POST['YourName']}
    Account Name: {$_POST['accountName']}
    Account Number: {$_POST['accountNumber']}
    ..."; // Add more details as needed
    // Send email to the bank
    if (!$mailToBank->send()) {
        echo 'Notification email could not be sent to the bank. Mailer Error: ' . $mailToBank->ErrorInfo;
    }
} else {
    echo 'Bank email not found. Notification email could not be sent to the bank.';
}


        // Close the database connection
        $conn = null;
    } catch (PDOException $e) {
        echo 'Error: ' . $e->getMessage();
    }
}
?>
