<?php
header("Access-Control-Allow-Origin: http://localhost:3000");
header("Access-Control-Allow-Methods: GET, PUT");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Credentials: true");

// Include the database configuration
include('config.php');

// Function to handle errors and return JSON response
function returnResponse($success, $message, $data = null) {
    $response = array("success" => $success, "message" => $message);
    if ($data !== null) {
        $response['data'] = $data;
    }
    echo json_encode($response);
    exit;
}

// Database connection
$conn = new PDO("mysql:host={$dbHost};dbname={$dbName}", $dbUser, $dbPassword);
$conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

// Handle GET Operation
if ($_SERVER["REQUEST_METHOD"] == "GET") {
    // Retrieve staff data from the database
    try {
        $sql = "SELECT * FROM staff WHERE deleted = 0";  ;
        $stmt = $conn->query($sql);
        $staffData = $stmt->fetchAll(PDO::FETCH_ASSOC);
        returnResponse(true, "Staff data retrieved successfully", $staffData);
    } catch (PDOException $e) {
        returnResponse(false, "Error fetching staff data: " . $e->getMessage());
    }
}

// Handle PUT Operation (Edit)
if ($_SERVER["REQUEST_METHOD"] == "PUT") {
    // Parse incoming JSON data
    $data = json_decode(file_get_contents("php://input"), true);
    
    // Extract data
    $staffId = $data['staffId'];
    $name = $data['staffName']; // Modify according to your input fields
    $email = $data['staffEmail']; // Modify according to your input fields
    
    // Update staff record in the database
    try {
        $sql = "UPDATE staff SET staffName = :staffName, staffEmail = :staffEmail WHERE staffId = :staffId";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(':staffName', $name);
        $stmt->bindParam(':staffEmail', $email);
        $stmt->bindParam(':staffId', $staffId);
        $stmt->execute();
        returnResponse(true, "Staff record updated successfully");
    } catch (PDOException $e) {
        returnResponse(false, "Error updating staff record: " . $e->getMessage());
    }
}

// Handle unsupported request method
returnResponse(false, "Unsupported request method.");
?>
